@@ -1,13 +1,13 @@
 package App::DuckPAN::DDG;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: DDG related functionality of duckpan
-$App::DuckPAN::DDG::VERSION = '0.193';
+$App::DuckPAN::DDG::VERSION = '0.195';
 use Moo;
 with 'App::DuckPAN::HasApp';
 
 use Module::Pluggable::Object;
 use Class::Load ':all';
-use Data::Printer;
+use Data::Printer return_value => 'dump';
 use List::Util qw (first);
 
 sub get_dukgo_user_pass {
@@ -158,7 +158,7 @@ App::DuckPAN::DDG - DDG related functionality of duckpan
 
 =head1 VERSION
 
-version 0.193
+version 0.195
 
 =head1 AUTHOR
 
