@@ -1,9 +1,9 @@
 package App::DuckPAN::Query;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Main application/loop for duckpan query
-$App::DuckPAN::Query::VERSION = '0.193';
+$App::DuckPAN::Query::VERSION = '0.195';
 use Moo;
-use Data::Printer;
+use Data::Printer return_value => 'dump';
 use POE qw( Wheel::ReadLine );
 use Try::Tiny;
 use open qw/:std :utf8/;
@@ -142,7 +142,7 @@ App::DuckPAN::Query - Main application/loop for duckpan query
 
 =head1 VERSION
 
-version 0.193
+version 0.195
 
 =head1 AUTHOR
 
