@@ -1,7 +1,7 @@
 package App::DuckPAN::Web;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.193';
+$App::DuckPAN::Web::VERSION = '0.195';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -14,7 +14,7 @@ use Plack::MIME;
 use HTML::Entities;
 use HTML::TreeBuilder;
 use HTML::Element;
-use Data::Printer;
+use Data::Printer return_value => 'dump';
 use HTTP::Request;
 use LWP::UserAgent;
 use URI::Escape;
@@ -564,7 +564,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.193
+version 0.195
 
 =head1 AUTHOR
 
